// Persistence of Vision Ray Tracer Scene Description File
// File: esr_demo.pov
// Vers: 3.5
// Desc: Demo-file for the Electro-Static-Repulsion Macro
// Date: 20.07.08 (dd.mm.yy)
// Auth: Tim Nikias Wenclawiak - www.NoLights.de

//Required Files
// "esr_macs.inc" - My ESR Macro to calculate the even distribution of spheres.

global_settings{
 assumed_gamma 1
 max_trace_level 25
 }

#include "esr_macs.inc"

#declare Amount_Of_Points=50;

//Generate a set of Amount_Of_Points points with according filename. I've kept the
//setup for the parsing times low, the more iterations, the more accurate it gets
ESR_Macro(
	Amount_Of_Points,							//Amount of Points (obviously ;-)
	1,											//Radius of the Sphere
	<0,0,0>,									//Center of the Sphere
	350,										//Iterations
	0.1,										//If the added forces are lower than this, the
												//iterations will stop early
	concat("",str(Amount_Of_Points,0,0),""),	//Filename (".esr" is added automatically)
	"ESR_Sphere",								//Name of the Array
	1)											//Overwrite-Switch, set to 1 to not overwrite
												//existing files

//Load the array with the even distribution
#include concat(str(Amount_Of_Points,0,0),".esr")

//Get the radius
#local Rad=Get_Min_Distance(ESR_Sphere)/2;

camera{location <0,0,-4> look_at <0,0,0>}
light_source{<-100,200,-300> rgb 1}

sphere{0,1 pigment{rgbt <1,0,0,.95>}}

#declare R=seed(26);

#declare Counter=0;
#while (Counter<Amount_Of_Points)
  sphere{ESR_Sphere[Counter],Rad
	  pigment{ rgb vnormalize(<rand(R)*3,rand(R)*3,rand(R)*3>)}
	}
  #declare Counter=Counter+1;
#end